@@ -13,14 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
-from google.cloud.bigquery_migration_v2.types import migration_error_details
-from google.cloud.bigquery_migration_v2.types import migration_metrics
-from google.cloud.bigquery_migration_v2.types import translation_config
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import error_details_pb2  # type: ignore
+import proto  # type: ignore
 
+from google.cloud.bigquery_migration_v2.types import (
+    migration_error_details,
+    migration_metrics,
+    translation_config,
+)
 
 __protobuf__ = proto.module(
     package="google.cloud.bigquery.migration.v2",
@@ -46,7 +47,7 @@ class MigrationWorkflow(proto.Message):
             The display name of the workflow. This can be
             set to give a workflow a descriptive name. There
             is no guarantee or enforcement of uniqueness.
-        tasks (Sequence[google.cloud.bigquery_migration_v2.types.MigrationWorkflow.TasksEntry]):
+        tasks (Mapping[str, google.cloud.bigquery_migration_v2.types.MigrationTask]):
             The tasks in a workflow in a named map. The
             name (i.e. key) has no meaning and is merely a
             convenient way to address a specific task in a
